# SGN Examples

This page serves as an index for the examples provided in the SGN documentation. Each example is a self-contained Python
script that demonstrates a specific feature of the SGN library.

## Examples

- [Trivial Example](trivial.md): A simple pipeline with a source and sink.
- [Simple Scalar Example](simple.md): A pipeline with a source, transform, and sink.
- [Simple JSON-Style Example](simple-json.md): A pipeline with a source, transform, and sink, using complex data structures.
